@@ -188,6 +188,49 @@ class ESManager(object):
         """
         return self.es.indices.refresh(index=self.index_name(name))
 
+    def setup_mapping(self, name, model_class):
+        """
+        Specify a mapping for a model class in a specific index
+
+        :param str name:
+        :param elasticgit.models.Model model_class:
+        :returns: dict
+        """
+        MappingType = self.get_mapping_type(model_class)
+        return self.setup_custom_mapping(
+            name, model_class, MappingType.get_mapping())
+
+    def setup_custom_mapping(self, name, model_class, mapping):
+        """
+        Specify a mapping for a model class in a specific index
+
+        :param str name:
+        :param elasticgit.models.Model model_class:
+        :param dict mapping: The Elasticsearch mapping definition
+        :returns: dict
+        """
+        MappingType = self.get_mapping_type(model_class)
+        return self.es.indices.put_mapping(
+            index=self.index_name(name),
+            doc_type=MappingType.get_mapping_type_name(),
+            body=mapping)
+
+    def get_mapping(self, name, model_class):
+        """
+        Retrieve a mapping for a model class in a specific index
+
+        :param str name:
+        :param elasticgit.models.Model model_class:
+        :returns: dict
+        """
+        index_name = self.index_name(name)
+        MappingType = self.get_mapping_type(model_class)
+        data = self.es.indices.get_mapping(
+            index=index_name,
+            doc_type=MappingType.get_mapping_type_name())
+        mappings = data[index_name]['mappings']
+        return mappings[MappingType.get_mapping_type_name()]
+
 
 class StorageException(Exception):
     pass
@@ -588,6 +631,35 @@ class Workspace(object):
         """
         return self.im.index_ready(self.repo.active_branch.name)
 
+    def setup_mapping(self, model_class):
+        """
+        Add a custom mapping for a model_class
+
+        :param elasticgit.models.Model model_class:
+        :returns: dict, the decoded dictionary from Elasticsearch
+        """
+        return self.im.setup_mapping(self.repo.active_branch.name, model_class)
+
+    def setup_custom_mapping(self, model_class, mapping):
+        """
+        Add a custom mapping for a model class instead of accepting
+        what the model_class defines.
+
+        :param elasticgit.models.Model model_class:
+        :param dict: the Elastisearch mapping definition
+        :returns: dict, the decoded dictionary from Elasticsearch
+        """
+        return self.im.setup_custom_mapping(
+            self.repo.active_branch.name, model_class, mapping)
+
+    def get_mapping(self, model_class):
+        """
+        Get a mapping from Elasticsearch for a model_class
+        :param elasticgit.models.Model model_class:
+        :returns: dict
+        """
+        return self.im.get_mapping(self.repo.active_branch.name, model_class)
+
     def S(self, model_class):
         """
         Get a :py:class:`elasticutils.S` object for the given
